tonalitytools.are_stepwise_ascending_notes
==========================================

.. autofunction:: abjad.tools.tonalitytools.are_stepwise_ascending_notes.are_stepwise_ascending_notes
   :noindex:
